@@ -41,7 +41,7 @@ describe ParallelTests::Test::Runner do
     end
 
     it "uses given when passed found" do
-      result = Gem.win_platform? && RUBY_VERSION.start_with?("2.4") ? [["a", "b"], ["c"]] : [["a", "c"], ["b"]]
+      result = Gem.win_platform? ? [["a", "b"], ["c"]] : [["a", "c"], ["b"]]
       expect(call(["a", "b", "c"], 2, group_by: :found)).to eq(result)
     end
 
